videocollection/hgmyvideos/inc/vcxhgmyvideosvideomodelhandler.h
branchRCL_3
changeset 21 55fa1ec415c6
parent 16 7f2b2a65da29
child 23 8f0df5c82986
--- a/videocollection/hgmyvideos/inc/vcxhgmyvideosvideomodelhandler.h	Tue Apr 27 16:40:33 2010 +0300
+++ b/videocollection/hgmyvideos/inc/vcxhgmyvideosvideomodelhandler.h	Tue May 11 16:15:40 2010 +0300
@@ -477,9 +477,9 @@
         TBool ValidOrigin( CMPXMedia& aMedia );
 
         /** 
          * Saves MPX id of highlighted item.
          */
-        void SaveHighlightedItemIdL();
+        void SaveFirstListItemIdL();
 
         /**
          * Update scrollbar strip type depending on sort order
@@ -576,15 +576,15 @@
         TInt iCurrentCategoryIndex;
 
         /**
          * Flag for indicating that highlight should restore to the position
          * where it was before model deactivating. 
          */ 
-        TBool iRestoreHighlightPosition;
+        TBool iRestoreListPosition;
         
         /**
          * MPX id of highlighted item in a video list.
          */
-        TMPXItemId iHighlightedItemId;
+        TMPXItemId iFirstListItemId;
 
         /**
          * Downloading has been resumed for these MPX IDs. Needed for showing
@@ -477,9 +477,9 @@
 
         /** 
-         * Saves MPX id of highlighted item.
+         * Saves MPX id of first (topmost) visible item.
          */
@@ -576,15 +576,15 @@
 
         /**
-         * Flag for indicating that highlight should restore to the position
+         * Flag for indicating that list should restore to the position
          * where it was before model deactivating. 
          */ 
@@ -576,15 +576,15 @@
         
         /**
-         * MPX id of highlighted item in a video list.
+         * MPX id of first (topmost) visible item in a video list.
          */